@@ -13,6 +13,7 @@
 from __future__ import absolute_import
 
 import importlib
+import os
 
 import mxnet as mx
 from sagemaker_inference import environment
@@ -23,6 +24,8 @@ from sagemaker_mxnet_serving_container.default_inference_handler import DefaultG
     DefaultMXNetInferenceHandler
 from sagemaker_mxnet_serving_container.mxnet_module_transformer import MXNetModuleTransformer
 
+PYTHON_PATH_ENV = "PYTHONPATH"
+
 
 class HandlerService(DefaultHandlerService):
     """Handler service that is executed by the model server.
@@ -54,7 +57,9 @@ class HandlerService(DefaultHandlerService):
         elif isinstance(model, mx.gluon.block.Block):
             return Transformer(default_inference_handler=DefaultGluonBlockInferenceHandler())
         else:
-            raise ValueError('Unsupported model type: {}'.format(model.__class__.__name__))
+            raise ValueError('Unsupported model type: {}. Did you forget to implement '
+                             '`transform_fn` or `model_fn` in your entry-point?'
+                             .format(model.__class__.__name__))
 
     def initialize(self, context):
         """Calls the Transformer method that validates the user module against
@@ -62,5 +67,13 @@ class HandlerService(DefaultHandlerService):
         """
         properties = context.system_properties
         model_dir = properties.get("model_dir")
+
+        # add model_dir/code to python path
+        code_dir_path = "{}:".format(model_dir + '/code')
+        if PYTHON_PATH_ENV in os.environ:
+            os.environ[PYTHON_PATH_ENV] = code_dir_path + os.environ[PYTHON_PATH_ENV]
+        else:
+            os.environ[PYTHON_PATH_ENV] = code_dir_path
+
         self._service = self._user_module_transformer(model_dir)
         super(HandlerService, self).initialize(context)
